library(rgdal)
library(gcmr)
library(maptools)
library(classInt)
library(spdep)
library(shapefiles)
library(CARBayes)

# read in the shape file and convert it to the British National Grid
dbf <- read.dbf(dbf.name="scot.dbf")
shp <- read.shp(shp.name="scot.shp")

scot_LL <- readOGR(".", "scot")

proj4string(scot_LL) = CRS("+proj=longlat +ellps=WGS84")
EPSG <- make_EPSG()
EPSG[grep("British National Grid", EPSG$note), 1:2]

scot_BNG0 <- spTransform(scot_LL, CRS("+init=epsg:27700"))



# read in the Scottish health data and merge with the names of the areas

scot_dat <- read.table("scotland.dat.txt", skip = 1)

names(scot_dat) <- c("District", "Observed", "Expected", "PcAFF",
                     "Latitude", "Longitude")

scot_dat = merge(x=scot_dat, y=dbf$dbf, by.x = "District", by.y="ID", all.x = T, all.y=F)

# create a set of smooth risks and add it to scot_dat as an extra column named SMR

# combine the estimate of risks with the shapefile

smr.matrix = as.matrix(scot_dat$SMR, ncol=1)[,1,drop=FALSE]
rownames(smr.matrix) = scot_dat$NAME

SMRspatial <- combine.data.shapefile(smr.matrix, shp, dbf)


# convert the geography of scot_dat to match the British National Grid
row.names(scot_dat) <- formatC(scot_dat$District, width = 2,
                               flag = "0")
ID <- formatC(scot_BNG0$ID, width = 2, flag = "0")
scot_BNG1 <- spChFIDs(scot_BNG0, ID)
scot_BNG <- spCbind(scot_BNG1, scot_dat[match(ID, row.names(scot_dat)),
                                        ])


# create a map of the risks, with diffetent colours for different ranges

